#include "sdl.h"
#include "sdl_mixer.h"
#include <vector>
#include <cstdio>
#include <cstdlib>

// Factor de conversion grados a radianes:
static constexpr float pi= M_PI;
static constexpr float factor= pi/180.0;
// Gráfico de nave, 5 puntos, 4 segmentos:
static const std::vector<sdl::FPoint> nave = { {15.0, 0.0}, {-15.0, -9.0}, {-11.0, 0.0}, {-15.0, 9.0}, {15.0, 0.0} };
static const std::vector<sdl::FPoint> estela = { {-16.0, -4.0}, {-25.0, 0.0}, {-16.0, 4.0} };
static const std::vector<sdl::Shape> formanave { sdl::FCircle(-6.0, 0.0, 9.0), sdl::FCircle(8.0, 0.0, 5.0) };

static const std::vector<std::vector<sdl::FPoint>> asteroide = {
    {{-5.0, -18.0}, {10.0, -16.0}, {19.0, -3.0}, {10.0, 7.0}, {11.0, 15.0}, {-5.0, 19.0}, {-18.0,8.0}, {-14.0, -7.0}, {-5.0, -18.0} },
    {{-10.0, -14.0}, {2.0, -14.0}, {11.0, 1.0}, {14.0, 1.0}, {8.0, 9.0}, {-2.0, 14.0}, {-9.0,6.0}, {-14.0, 4.0}, {-9.0, -5.0}, {-10.0,-14.0} },
    {{-4.0, -10.0}, {2.0, -10.0}, {9.0, -6.0}, {5.0, 1.0}, {8.0, 5.0}, {0.0, 9.0}, {-5.0,-2.0}, {-7.0, -4.0}, {-4.0, -10.0} }};
static const std::vector<std::vector<sdl::Shape>> forma = {
    { sdl::FCircle(0, 0, 19) },
    { sdl::FCircle(0, 0, 14) },
    { sdl::FCircle(0, 0, 10) }
};
static const std::vector<sdl::FPoint> disparo = { {-1.0, 0.0}, {0.0, 1.0}, {1.0, 0.0}, {0.0, -1.0}, {-1.0, 0.0} };
static const std::vector<sdl::Shape> formadisparo { sdl::FCircle(0.0, 0.0 ,1.0) };

enum tipoAsteroide {
    grande=0,
    mediano,
    pequeno,
    nada
};

class Nave {
private:
    std::vector<sdl::FPoint> nave2;
    std::vector<sdl::FPoint> estela2;
    sdl::Hitbox hitbox;
    sdl::FPoint posicion;
    sdl::FPoint velocidad;
    void trasladar(float alfa, sdl::FPoint &desplazamiento, sdl::FPoint &escala) {
        for(size_t i = 0; i < nave.size(); i++) {
            nave2[i] = nave[i].Move(alfa, desplazamiento, escala);
        }
        for(size_t i = 0; i < estela.size(); i++) {
            estela2[i] = estela[i].Move(alfa, desplazamiento, escala);
        }
    }

public:
    Nave(const sdl::FPoint &pos, const float alfa) : posicion(pos), velocidad(0.0, 0.0) {
        nave2.resize(nave.size());
        estela2.resize(estela.size());
        for(size_t i=0; i<formanave.size(); i++) hitbox.InsertShape(formanave[i]);
        hitbox.ResizeT();
    }
    void Actualizar(Uint64 tick, float acelerar, float alfa, sdl::FPoint escala) {
        velocidad.X() += acelerar*cos(factor*alfa);
        velocidad.Y() += -acelerar*sin(factor*alfa);
        posicion.X() += (velocidad.X()*(tick)/1000.0);
        posicion.Y() += (velocidad.Y()*(tick)/1000.0);
        if(posicion.X()>635) posicion.X() -=640;
        if(posicion.X()<5) posicion.X() +=640;
        if(posicion.Y()>475) posicion.Y() -=480;
        if(posicion.Y()<5) posicion.Y() +=480;
        // Trasladar nave:
        trasladar(factor*alfa, posicion, escala);
        // Trasladar hitbox:
        hitbox.Move(factor*alfa, posicion, escala);
    }
    std::vector<sdl::FPoint> &PuntosNave() { return nave2; }
    std::vector<sdl::FPoint> &PuntosEstela() { return estela2; }
    sdl::FPoint Posicion() { return posicion; }
    sdl::FPoint Velocidad() { return velocidad; }
    sdl::Hitbox &Hitbox() { return hitbox; }
};

class Asteroide {
private:
    std::vector<sdl::FPoint> asteroide2;
    tipoAsteroide tipo;
    sdl::FPoint posicion;
    sdl::FPoint velocidad;
    float alfa; // En radianes
    float vRotacion; // En radianes/tick
    sdl::Hitbox hitbox;
    bool activo;
    void Trasladar(float alfa, sdl::FPoint &desplazamiento, sdl::FPoint &escala) {
    // x' = x * x" * cos(α) + y * y" * sin(α) + dx
    // y' = -x * x" * sin(α) + y * y" * cos(α) + dy
        for(size_t i = 0; i < asteroide2.size(); i++) {
            asteroide2[i] = asteroide[tipo][i].Move(alfa, desplazamiento, escala);
        }
    }
public:
    Asteroide(const sdl::FPoint &pos, tipoAsteroide t) : tipo(t), posicion(pos),
        alfa(360.0*std::rand()/RAND_MAX), activo(true) {
        asteroide2.resize(asteroide[tipo].size());
        float v = 100.0*std::rand()/RAND_MAX;
        alfa = 2.0*pi*std::rand()/RAND_MAX;
        velocidad = {v*(float)cos(alfa), v*(float)sin(alfa)};
        vRotacion = -5.0+10.0*std::rand()/RAND_MAX;
        for(size_t i=0; i<forma[tipo].size(); i++) hitbox.InsertShape(forma[tipo][i]);
        hitbox.ResizeT();
    }
    Asteroide(const sdl::FPoint &pos, tipoAsteroide t, const sdl::FPoint &vel) : tipo(t), posicion(pos), velocidad(vel) {
        vRotacion = -5.0+10.0*std::rand()/RAND_MAX;
        for(size_t i=0; i<forma[tipo].size(); i++) hitbox.InsertShape(forma[tipo][i]);
        asteroide2.resize(asteroide[tipo].size());
        hitbox.ResizeT();
        }
    void Actualizar(Uint64 tick, sdl::FPoint escala) {
        posicion.X() += (velocidad.X()*(tick)/1000.0);
        posicion.Y() += (velocidad.Y()*(tick)/1000.0);
        alfa += vRotacion *(tick)/1000.0;
        if(alfa > 2*pi) alfa -= 2*pi;
        if(alfa < 0) alfa += 2*pi;
        if(posicion.X()>645) posicion.X() -=650;
        if(posicion.X()<-5) posicion.X() +=650;
        if(posicion.Y()>485) posicion.Y() -=490;
        if(posicion.Y()<-5) posicion.Y() +=490;
        // Trasladar asteroide:
        Trasladar(alfa, posicion, escala);
        // Trasladar hitbox:
        hitbox.Move(alfa, posicion, escala);
    }
    tipoAsteroide &Tipo() { return tipo; }
    void CambiarTipo(tipoAsteroide tipo);
    sdl::FPoint &Posicion() { return posicion; }
    sdl::FPoint &Velocidad() { return velocidad; }
    bool Colision(Asteroide &a) {
        return hitbox.Collision(a.hitbox);
    }
    sdl::Hitbox &Hitbox() { return hitbox; }
    std::vector<sdl::FPoint> &Puntos() { return asteroide2; }
    bool Activo() { return activo; }
    void Desactivar() { activo=false; }
};

void Asteroide::CambiarTipo(tipoAsteroide t) {
    tipo = t;
    vRotacion = -5.0+10.0*std::rand()/RAND_MAX;
    hitbox.Reset();
    for(size_t i=0; i<forma[tipo].size(); i++) hitbox.InsertShape(forma[tipo][i]);
    asteroide2.resize(asteroide[tipo].size());
    hitbox.ResizeT();
}

class Disparo {
private:
    std::vector<sdl::FPoint> disparo2;
    sdl::FPoint posicion;
    sdl::FPoint velocidad;
    sdl::Hitbox hitbox;
    float ticksvida;
    bool activo;

    void Trasladar(sdl::FPoint &desplazamiento, sdl::FPoint &escala) {
    // x' = x * x" * cos(α) + y * y" * sin(α) + dx
    // y' = -x * x" * sin(α) + y * y" * cos(α) + dy
        for(size_t i = 0; i < disparo2.size(); i++) {
            disparo2[i] = disparo[i].Move(0.0, desplazamiento, escala);
        }
    }

public:
    // Sumamos 100.0 a la velocidad de la nave:
    Disparo(sdl::FPoint pos, float alfa, sdl::FPoint v) : posicion(pos),
        velocidad(v.X()+150*SDL_cosf(factor*alfa), v.Y()-150*SDL_sinf(factor*alfa)), ticksvida(2000), activo(true) {
        disparo2.resize(disparo.size());
        for(size_t i=0; i<formadisparo.size(); i++) hitbox.InsertShape(formadisparo[i]);
        hitbox.ResizeT();
    }
    void Actualizar(Uint64 tick, sdl::FPoint escala) {
        ticksvida -= tick;
        if(ticksvida < 0) activo=false;
        else {
            posicion.X() += (velocidad.X()*(tick)/1000.0);
            posicion.Y() += (velocidad.Y()*(tick)/1000.0);
            if(posicion.X()>645) posicion.X() -=650;
            if(posicion.X()<-5) posicion.X() +=650;
            if(posicion.Y()>485) posicion.Y() -=490;
            if(posicion.Y()<-5) posicion.Y() +=490;
            // Trasladar asteroide:
            Trasladar(posicion, escala);
            // Trasladar hitbox:
            hitbox.Move(0.0, posicion, escala);
        }
    }
    bool Activo() { return activo; }
    void Desactivar() { activo=false; }
    sdl::FPoint &Posicion() { return posicion; }
    sdl::FPoint &Velocidad() { return velocidad; }
    std::vector<sdl::FPoint> &Puntos() { return disparo2; }
    bool Colision(Asteroide &a) {
        return hitbox.Collision(a.Hitbox());
    }
};

class Asteroides : public sdl::Game, sdl::Mixer {
private:
    sdl::FPoint escala; // Escala del juego (ajustada a una resolución de 640x480
    std::vector<sdl::FPoint> estrellas;
    Nave nave;
    std::vector<Disparo> disparos;
    std::vector<Asteroide> asteroides;
    float acelerar;
    float alfa;
    bool disparo;
    void RebotarAsteroides(int a, int b);
    void DividirAsteroide(int iAst, int iDis);
    void DestruirNave() { explosion[1].Play(); }
    bool ColisionNave(int iAsteroide) { return asteroides[iAsteroide].Hitbox().Collision(nave.Hitbox()); }
    sdl::Music musica;
    sdl::Chunk explosion[3];
    sdl::Chunk laser;

public:
    Asteroides(sdl::Window& window, sdl::Renderer& renderer) :
      sdl::Game(window, renderer, 800, 600),
      sdl::Mixer(MIX_INIT_MID|MIX_INIT_OGG), nave({320.0, 240.0}, 0.0),
      acelerar(0.0), alfa(0.0), disparo(false),
      musica("asi_hablo_zaratustra_amanecer.mid"),
      explosion {"explosion1.ogg", "explosion2.ogg", "explosion3.ogg"},
      laser("laser3.mp3") {
        static int w, h;
        window.GetSize(&w, &h);
        escala = sdl::FPoint(w/640.0, h/480.0);
        musica.Play(0);
        for(int i=0; i<500; i++) {
            estrellas.push_back({static_cast<float>(w*rand()/RAND_MAX), static_cast<float>(h*rand()/RAND_MAX)});
        }
    }
    int random(int n) { return static_cast<int>(3*rand()/RAND_MAX); }
    const sdl::FPoint &Escala() { return escala; }
    void Init();
    void Events();
    void Update();
    void Render();
};

void Asteroides::Events() {
    static bool izq;
    static bool der;
    static bool arr;
    static bool dis;

    while(event.Poll()) {
        switch(event.Type()) {
        case SDL_KEYDOWN:
            if(event.Key().keysym.sym == SDLK_LEFT)  { izq = true; }
            if(event.Key().keysym.sym == SDLK_RIGHT) { der = true; }
            if(event.Key().keysym.sym == SDLK_UP)    { arr = true; }
            if(event.Key().keysym.sym == SDLK_SPACE && !dis) { dis = disparo = true; }
            if(event.Key().keysym.sym == SDLK_ESCAPE) { quit = true; }
            break;
        case SDL_KEYUP:
            if(event.Key().keysym.sym == SDLK_LEFT)  { izq = false; }
            if(event.Key().keysym.sym == SDLK_RIGHT) { der = false; }
            if(event.Key().keysym.sym == SDLK_UP)    { arr = false; }
            if(event.Key().keysym.sym == SDLK_SPACE) { dis = false; }
            break;
        }
    }
    acelerar = 0.0;
    if(izq && !der) alfa -= tick/10.0;
    if(!izq && der) alfa += tick/10.0;
    if(alfa < 0) alfa+=360.0;
    if(alfa >= 360.0) alfa-=360.0;
    if(arr) acelerar = tick/15.0;
}

void Asteroides::Render() {
    sdl::FRect re;
    sdl::Color negro("#000000ff");
    sdl::Color blanco("#ffffffff");
    sdl::Color naranja("#ffff00ff");
    sdl::Color rojo("#ff0000ff");
    sdl::Color verde("#00ff00ff");

    // Renderizado:
    renderer.SetDrawColor(negro);
    renderer.Clear();
    renderer.SetDrawColor(blanco);
    for(size_t i=0; i<estrellas.size(); i++)
        renderer.DrawPoint(estrellas[i]);
    renderer.DrawLinesF(nave.PuntosNave());

#ifdef VERHITBOX
    re=sdl::FRect(nave.Hitbox().GetForma(0).Ci().X()-nave.Hitbox().GetForma(0).Ci().R(),
        nave.Hitbox().GetForma(0).Ci().Y()-nave.Hitbox().GetForma(0).Ci().R(),
        nave.Hitbox().GetForma(0).Ci().R()*2, nave.Hitbox().GetForma(0).Ci().R()*2);
    renderer.DrawRect(re);
    re=sdl::FRect(nave.Hitbox().GetForma(1).Ci().X()-nave.Hitbox().GetForma(1).Ci().R(),
        nave.Hitbox().GetForma(1).Ci().Y()-nave.Hitbox().GetForma(1).Ci().R(),
        nave.Hitbox().GetForma(1).Ci().R()*2, nave.Hitbox().GetForma(1).Ci().R()*2);
    renderer.DrawRect(re);
    for(size_t i=0; i<asteroides.size(); i++) {
        if(asteroides[i].Activo()) {
            re=sdl::FRect(asteroides[i].Hitbox().GetForma(0).Ci().X()-asteroides[i].Hitbox().GetForma(0).Ci().R(),
                asteroides[i].Hitbox().GetForma(0).Ci().Y()-asteroides[i].Hitbox().GetForma(0).Ci().R(),
                asteroides[i].Hitbox().GetForma(0).Ci().R()*2, asteroides[i].Hitbox().GetForma(0).Ci().R()*2);
            renderer.DrawRect(re);
        }
    }
#endif // VERHITBOX
    if(acelerar != 0.0) {
        renderer.SetDrawColor(naranja);
        renderer.DrawLinesF(nave.PuntosEstela());
    }
    // Disparos:
    renderer.SetDrawColor(rojo);
    for(size_t i=0; i<disparos.size(); i++)
        if(disparos[i].Activo())
            renderer.DrawLinesF(disparos[i].Puntos());
    // Asteroides:
    renderer.SetDrawColor(verde);
    for(size_t i=0; i<asteroides.size(); i++) {
        if(asteroides[i].Activo()) {
            renderer.DrawLinesF(asteroides[i].Puntos());
        }
    }
    renderer.Present();
}

void Asteroides::Update() {
    bool insertado = false;

    nave.Actualizar(tick, acelerar, alfa, escala);
    for(size_t i=0; i<asteroides.size(); i++) asteroides[i].Actualizar(tick, escala);
    for(size_t i=0; i<disparos.size(); i++) disparos[i].Actualizar(tick, escala);
    // Detectar colisiones
    for(size_t i=0; i<asteroides.size()-1; i++) {
        if(asteroides[i].Activo()) {
            for(size_t j=i+1; j<asteroides.size(); j++) {
                if(asteroides[j].Activo() && asteroides[i].Colision(asteroides[j])) {
                    RebotarAsteroides(i, j);
                }
            }
        }
    }
    for(size_t i=0; i<disparos.size(); i++) {
        if(disparos[i].Activo()) {
            for(size_t j=0; j<asteroides.size(); j++) {
                if(asteroides[j].Activo() && disparos[i].Colision(asteroides[j])) {
                    DividirAsteroide(j, i);
                    int exp = random(3);
                    // Calcular angulo y distancia con respecto a centro de ventana
                    float angulo = 180.0*(SDL_atan2f(disparos[i].Posicion().Y()-240.0, disparos[i].Posicion().X()-320.0)+pi/2)/pi;
                    while(angulo < 0) angulo+=360;
                    float distancia = (disparos[i].Posicion().X()-320.0)*(disparos[i].Posicion().X()-320.0)+
                        (disparos[i].Posicion().Y()-240.0)*(disparos[i].Posicion().Y()-240.0);
                    distancia = 255.0*(distancia/(320.0*320.0));
                    explosion[exp].Play();
                    explosion[exp].SetPosition(static_cast<Sint16>(angulo), static_cast<Uint8>(distancia));
                    disparos[i].Desactivar();
                }
            }
        }
    }
    for(size_t i=0; i<asteroides.size(); i++) {
        if(asteroides[i].Activo() && ColisionNave(i)) {
            DestruirNave();
        }
    }

    if(disparo) {
        // Buscar un disparo inactivo:
        for(size_t i=0; i<disparos.size() && !insertado; i++) {
            if(!disparos[i].Activo()) {
                disparos[i] = Disparo(nave.Posicion(),alfa, nave.Velocidad());
                insertado = true;
            }
        }
        if(!insertado) disparos.push_back(Disparo(nave.Posicion(), alfa, nave.Velocidad()));
        disparo=false;
        laser.Play(1);
    }
}

void Asteroides::RebotarAsteroides(int a, int b) {
    sdl::FPoint V1, V2;
    float theta;
    float m1,m2;

    m1 = (asteroides[a].Tipo()==grande) ? 4.0: (asteroides[a].Tipo()==mediano) ? 2.0:1.0;
    m2 = (asteroides[b].Tipo()==grande) ? 4.0: (asteroides[b].Tipo()==mediano) ? 2.0:1.0;
    // Calcular el ángulo normal:
    // θ = atan2(y2-y1, x2-x1)
    theta = SDL_atan2f(asteroides[b].Posicion().Y()-asteroides[a].Posicion().Y(),
                       asteroides[b].Posicion().X()-asteroides[a].Posicion().X());
    // Calcular componentes normal y transversal de las velocidades
    // Vn =  Vx · cos(θ) + Vy · sin(θ)
    // Vt = -Vx · sin(θ) + Vy · cos(θ)
    V1.X() =  asteroides[a].Velocidad().X()*cos(theta)+asteroides[a].Velocidad().Y()*sin(theta);
    V1.Y() = -asteroides[a].Velocidad().X()*sin(theta)+asteroides[a].Velocidad().Y()*cos(theta);
    V2.X() =  asteroides[b].Velocidad().X()*cos(theta)+asteroides[b].Velocidad().Y()*sin(theta);
    V2.Y() = -asteroides[b].Velocidad().X()*sin(theta)+asteroides[b].Velocidad().Y()*cos(theta);
    // Calcular nuevas direcciones
    // v1fn = (2·v2in·m2+v1in·(m1-m2))/(m1+m2)
    // v2fn = (2·v1in·m1+v2in·(m2-m1))/(m1+m2)
    // v1ft = v1it
    // v2ft = v2it
    float v2n = (2*V1.X()*m1+V2.X()*(m2-m1))/(m1+m2);
    float v1n = (2*V2.X()*m2+V1.X()*(m1-m2))/(m1+m2);
    V1.X() = v1n;
    V2.X() = v2n;
    // Recalcular componentes ortogonales:
    // Vx = Vn · cos(θ) - Vt · sin(θ)
    // Vy = Vn · sin(θ) + Vt · cos(θ)
    asteroides[a].Velocidad().X() = V1.X()*cos(theta)-V1.Y()*sin(theta);
    asteroides[a].Velocidad().Y() = V1.X()*sin(theta)+V1.Y()*cos(theta);
    asteroides[b].Velocidad().X() = V2.X()*cos(theta)-V2.Y()*sin(theta);
    asteroides[b].Velocidad().Y() = V2.X()*sin(theta)+V2.Y()*cos(theta);
//    sdl::FPoint v1(asteroides[a].Velocidad());
//    sdl::FPoint v2(asteroides[b].Velocidad());
}

void Asteroides::DividirAsteroide(int iAsteroide, int iDisparo) {
    sdl::FPoint V1, V2;
    float theta;
    float m1,m2;
    float v1n,v2n;
    sdl::FPoint p1, p2, p2b;
    tipoAsteroide tipo;

    if(asteroides[iAsteroide].Tipo()==pequeno) {
        asteroides[iAsteroide].Desactivar();
        return;
    }
    tipo = (asteroides[iAsteroide].Tipo()==grande) ? mediano:pequeno;
    m1 = (asteroides[iAsteroide].Tipo()==grande) ? 4.0:2.0;
    m2 = 8;
    // Calcular el ángulo normal:
    // θ = atan2(y2-y1, x2-x1)
    theta = SDL_atan2f(disparos[iDisparo].Posicion().Y()-asteroides[iAsteroide].Posicion().Y(),
                       disparos[iDisparo].Posicion().X()-asteroides[iAsteroide].Posicion().X());
    // Calcular componentes normal y transversal de las velocidades y posicion de asteroide
    // Vn =  Vx · cos(θ) + Vy · sin(θ)
    // Vt = -Vx · sin(θ) + Vy · cos(θ)
    V1.X() =  asteroides[iAsteroide].Velocidad().X()*cos(theta)+asteroides[iAsteroide].Velocidad().Y()*sin(theta);
    V1.Y() = -asteroides[iAsteroide].Velocidad().X()*sin(theta)+asteroides[iAsteroide].Velocidad().Y()*cos(theta);
    p1.X() =  asteroides[iAsteroide].Posicion().X()*cos(theta)+asteroides[iAsteroide].Posicion().Y()*sin(theta);
    p1.Y() = -asteroides[iAsteroide].Posicion().X()*sin(theta)+asteroides[iAsteroide].Posicion().Y()*cos(theta);
    V2.X() =  disparos[iDisparo].Velocidad().X()*cos(theta)+disparos[iDisparo].Velocidad().Y()*sin(theta);
    V2.Y() = -disparos[iDisparo].Velocidad().X()*sin(theta)+disparos[iDisparo].Velocidad().Y()*cos(theta);
    // Calcular nuevas direcciones
    // v1fn = (2·v2in·m2+v1in·(m1-m2))/(m1+m2)
    // v2fn = (2·v1in·m1+v2in·(m2-m1))/(m1+m2)
    // v1ft = v1it
    // v2ft = v2it
    v1n = v2n = (2*V1.X()*m1+V2.X()*(m2-m1))/(m1+m2);
    V1.X() = V2.X() = v1n;
    // Sumar velocidades de separación
    V1.Y() -= 100;
    V2.Y() += 100;
    // Trasladar las posiciones tangencialmente:
    p2 = p1;
    p1.Y() -= 15;
    p2.Y() += 15;
    // Recalcular componentes ortogonales de velocidad y posicion:
    // Vx = Vn · cos(θ) - Vt · sin(θ)
    // Vy = Vn · sin(θ) + Vt · cos(θ)
    asteroides[iAsteroide].Velocidad().X() = V1.X()*cos(theta)-V1.Y()*sin(theta);
    asteroides[iAsteroide].Velocidad().Y() = V1.X()*sin(theta)+V1.Y()*cos(theta);
    asteroides[iAsteroide].Posicion().X() = p1.X()*cos(theta)-p1.Y()*sin(theta);
    asteroides[iAsteroide].Posicion().Y() = p1.X()*sin(theta)+p1.Y()*cos(theta);
    p2b.X() = p2.X()*cos(theta)-p2.Y()*sin(theta);
    p2b.Y() = p2.X()*sin(theta)+p2.Y()*cos(theta);

    asteroides[iAsteroide].CambiarTipo(tipo);
    sdl::FPoint v2 = {V2.X()*SDL_cosf(theta)-V2.Y()*SDL_sinf(theta), V2.X()*SDL_sinf(theta)+V2.Y()*SDL_cosf(theta)};
    asteroides.push_back(Asteroide(p2b, tipo, v2));
    asteroides[iAsteroide].Actualizar(0, escala);
    asteroides[asteroides.size()-1].Actualizar(0, escala);
}

void Asteroides::Init() {
    // Añadir 5 asteroides grandes
    for(int i=0; i<5; i++) {
        asteroides.push_back(Asteroide({static_cast<float>(640.0*rand()/RAND_MAX), static_cast<float>(480.0*rand()/RAND_MAX)}, grande));
    }
}

int main( int argc, char * argv[] ) {
    sdl::SDL2 sdl(SDL_INIT_EVERYTHING);
    sdl::Window window ("Asteroides", 800, 600, (SDL_WindowFlags)(SDL_WINDOW_SHOWN | SDL_WINDOW_BORDERLESS));
    sdl::Renderer renderer(window, SDL_RENDERER_ACCELERATED);

    Asteroides asteroides(window, renderer);

    asteroides.Run();
    return 0;
}

