/*
 * Clases para manejar Chunk de SDL_mixer
 * Mix_LoadWAV
 * Mix_FreeChunk
 * Mix_PlayChannel
 */

#ifndef _SDL_CHUNK
#define _SDL_CHUNK

#include <SDL.h>
#include <SDL_mixer.h>

namespace sdl {

class Chunk {
protected:
    Mix_Chunk *chunk;
    int channel;

public:
    Chunk() { chunk=NULL; }
    Chunk(const char *file) {
        chunk = Mix_LoadWAV(file);
    }
    ~Chunk() {
        Mix_FreeChunk(chunk);
    }
    int Play(int ch=-1, int loops=0) {
        channel = Mix_PlayChannel(ch, chunk, loops);
        return channel;
    }
    int MasterVolumen(int volumen) {
        return Mix_MasterVolume(volumen);
    }
    int Volumen(int volumen) {
        return Mix_Volume(channel, volumen);
    }
    void Pausa() {
        Mix_Pause(channel);
    }
    void Resume() {
        Mix_Resume(channel);
    }
    bool Pausado() {
        return Mix_Paused(channel);
    }
    int Halt() {
        return Mix_HaltChannel(channel);
    }
    int FadeIn(int loops=0, int ms=1000) {
        return Mix_FadeInChannel(channel, chunk, loops, ms);
    }
    int FadeInTimed(int loops=0, int ms=1000, int ticks=-1) {
        return Mix_FadeInChannelTimed(channel, chunk, loops, ms, ticks);
    }
    int FadeOut(int ms) {
        return Mix_FadeOutChannel(channel, ms);
    }
    Mix_Fading Fading() {
        return Mix_FadingChannel(channel);
    }
    int SetPosition(Sint16 angle, Uint8 distance) {
        return Mix_SetPosition(channel, angle, distance);
    }
};
} // namespace

#endif // _SDL_CHUNK

