/*
 * Clases para manejar circulos en SDL2
 */
#ifndef _SDL_CIRCLE
#define _SDL_CIRCLE

#include <SDL.h>
#include <cmath>

namespace sdl {

class Circle {
protected:
    Point center;
    int radius;
public:
    Circle(int x=0, int y=0, int r=0) : center(x, y), radius(r) {}
    Circle(Point &c, int r=0) : center(c), radius(r) {}
    Point &Center() { return center; }
    int &X() { return center.X(); }
    int &Y() { return center.Y(); }
    int &R() { return radius; }
};

class FCircle {
protected:
    FPoint center;
    float radius;
public:
    FCircle(float x=0, float y=0, float r=0) : center(x, y), radius(r) {}
    FCircle(FPoint &c, float r=0) : center(c), radius(r) {}
    FCircle Move(float alfa, sdl::FPoint &displacement, sdl::FPoint &escale) {
        // x' = x * x" * cos(α) + y * y" * sin(α) + dx
        // y' = -x * x" * sin(α) + y * y" * cos(α) + dy
        return {escale.X()*center.X() * static_cast<float>(cos(alfa)) +
                escale.Y()*center.Y() * static_cast<float>(sin(alfa)) + escale.X()*displacement.X(),
                -escale.X()*center.X() * static_cast<float>(sin(alfa)) +
                escale.Y()*center.Y() * static_cast<float>(cos(alfa)) + escale.Y()*displacement.Y(),
                escale.X()*radius};
    }
    FPoint &Center() { return center; }
    float &X() { return center.X(); }
    float &Y() { return center.Y(); }
    float &R() { return radius; }
};

} // namespace

#endif // _SDL_CIRCLE

