/*
 * Clases para manejar un color en SDL2
 */
#ifndef _SDL_COLOR
#define _SDL_COLOR

#include <SDL.h>
#include <string>

namespace sdl {

class Color {
private:
    SDL_Color color;

public:
    Color(Uint8 r, Uint8 g, Uint8 b, Uint8 a=255) {
        color.r=r;
        color.g=g;
        color.b=b;
        color.a=a;
    }
    Color(const std::string c) { // Formato #RRGGBBAA, RRGGBBAA, #RRGGBB, RRGGBB, #RGBA, #RGB, RGBA, RGB
        std::string col = c;
        std::string R, G, B, A;

        if(c.substr(0,1) == "#") col = c.substr(1);
        else col = c;
        switch(col.size()) {
        case 8: // RRGGBBAA
            color.a = stoi(col.substr(6,2), nullptr, 16);
        case 6: // RRGGBB
            color.r = stoi(col.substr(0,2), nullptr, 16);
            color.g = stoi(col.substr(2,2), nullptr, 16);
            color.b = stoi(col.substr(4,2), nullptr, 16);
            break;
        case 4: // RGBA
            A = col.substr(3,1)+col.substr(3,1);
            color.a = stoi(A, nullptr, 16);
        case 3: // RGB
            R = col.substr(0,1)+col.substr(0,1);
            G = col.substr(1,1)+col.substr(1,1);
            B = col.substr(2,1)+col.substr(2,1);
            color.r = stoi(R, nullptr, 16);
            color.g = stoi(G, nullptr, 16);
            color.b = stoi(B, nullptr, 16);
            break;
        }
    }
    operator SDL_Color() { return color; }
    Uint8 GetR() const { return color.r; }
    Uint8 GetG() const { return color.g; }
    Uint8 GetB() const { return color.b; }
    Uint8 GetA() const { return color.a; }
};

} // namespace

#endif // header

