/*
 * Clases para manejar juegos en SDL2
 */
#ifndef _SDL_GAME
#define _SDL_GAME

#include <SDL.h>
#include <string>
#include <cstdlib>
#include <ctime>

namespace sdl {

int random(int n) {
    float r = std::rand()/static_cast<float>(RAND_MAX);
    return n*(static_cast<float>(r));
}

float randomf(float n) {
    float r = std::rand()/static_cast<float>(RAND_MAX);
    return n*(static_cast<float>(r));
}

class Game {
protected:
    Window& window;
    Renderer& renderer;
    Uint64 tick, tick0;
    Event event;
    bool quit;

public:
    Game(Window &win, Renderer &ren, int w=800, int h=600) : window(win), renderer(ren), quit(false) {
        window.SetSize(w, h);
        window.Center();
        std::srand(std::time(NULL));
    }

    Window &getWindow() { return window; }
    Renderer &getRenderer() { return renderer; }
    bool Quit() { return quit; }
    virtual void Init()=0;
    virtual void Events()=0;
    virtual void Update()=0;
    virtual void Render()=0;
    virtual void Run();
};

void Game::Run() {
    Init();
    tick0 = SDL_GetTicks64();
    do {
        tick = SDL_GetTicks64()-tick0;
        tick0 = SDL_GetTicks64();
        Events();
        Update();
        Render();
        SDL_Delay(1);
    } while(!Quit());
}

} // namespace sdl
#endif // _SDL_JUEGO
