/*
 * Clases para manejar música SDL_mixer
 * Mix_LoadMUS
 * Mix_FreeMusic
 * Mix_PlayMusic
 */

#ifndef _SDL_MUSIC
#define _SDL_MUSIC

#include <SDL.h>
#include <SDL_mixer.h>

namespace sdl {

class Music {
protected:
    Mix_Music *music;

public:
    Music() { music=NULL; }
    Music(const char *file) {
        music = Mix_LoadMUS(file);
    }
    ~Music() {
        Mix_FreeMusic(music);
    }
    void Play(int loops) {
        Mix_PlayMusic(music, loops);
    }
    int Volume(int volume) {
        return Mix_VolumeMusic(volume);
    }
    void Pause() {
        Mix_PausedMusic();
    }
    void Resume() {
        Mix_ResumeMusic();
    }
    bool Paused() {
        return Mix_PausedMusic();
    }
    void Halt() {
        Mix_HaltMusic();
    }
    int FadeIn(int loops=0, int ms=1000) {
        return Mix_FadeInMusic(music, loops, ms);
    }
    int FadeInPos(int loops=0, int ms=1000, double pos=0.0) {
        return Mix_FadeInMusicPos(music, loops, ms, pos);
    }
    int FadeOut(int ms) {
        return Mix_FadeOutMusic(ms);
    }
    Mix_Fading Fading() {
        return Mix_FadingMusic();
    }
};
} // namespace

#endif // _SDL_MUSIC
