/*
 * Clases para manejar puntos en SDL2
 * SDL_Point
 * SDL_FPoint
 */
#ifndef _SDL_POINT
#define _SDL_POINT

#include <SDL.h>
#include <cmath>

namespace sdl {

class Point {
protected:
    SDL_Point point;
public:
    Point(int x=0, int y=0) {
        point.x = x;
        point.y = y;
    }
    Point(SDL_Point &p) : point(p) {}
    SDL_Point *Get() { return &point; }
    int &X() { return point.x; }
    int &Y() { return point.y; }
};

class FPoint {
protected:
    SDL_FPoint point;
public:
    FPoint(float x=0.0, float y=0.0) {
        point.x = x;
        point.y = y;
    }
    FPoint(SDL_FPoint &p) : point(p) {}
    SDL_FPoint &Get() { return point; }
    FPoint Move(float alfa, const sdl::FPoint &displacement, const sdl::FPoint &escale) const {
        // x' = x * x" * cos(α) + y * y" * sin(α) + dx
        // y' = -x * x" * sin(α) + y * y" * cos(α) + dy
        return {
            escale.point.x*point.x * static_cast<float>(cos(alfa)) +
            escale.point.y*point.y * static_cast<float>(sin(alfa)) +
            escale.point.x*displacement.point.x,
            -escale.point.x*point.x * static_cast<float>(sin(alfa)) +
            escale.point.y*point.y * static_cast<float>(cos(alfa)) +
            escale.point.y*displacement.point.y};
    }
    float &X() { return point.x; }
    float &Y() { return point.y; }
};

} // namespace

#endif // _SDL_POINT
