/*
 * Clases para manejar rectángulos en SDL2
 * SDL_Rect
 * SDL_FRect
 */
#ifndef _SDL_RECT
#define _SDL_RECT

#include <SDL.h>
#include <cmath>

namespace sdl {

class Rect {
protected:
    SDL_Rect rect;
public:
    Rect(int x=0, int y=0, int w=0, int h=0) {
        rect.x = x;
        rect.y = y;
        rect.w = w;
        rect.h = h;
    }
    Rect(SDL_Rect r) : rect(r) {}
    SDL_Rect *get() { return &rect; }
    int &X() { return rect.x; }
    int &Y() { return rect.y; }
    int &W() { return rect.w; }
    int &H() { return rect.h; }
};

class FRect {
protected:
    SDL_FRect rect;
public:
    FRect(float x=0.0, float y=0.0, float w=0.0, float h=0.0) {
        rect.x = x;
        rect.y = y;
        rect.w = w;
        rect.h = h;
    }
    FRect(SDL_FRect &r) : rect(r) {}
    SDL_FRect *get() { return &rect; }
    SDL_FRect &Rect() { return rect; }
    FPoint Corner() { return FPoint(rect.x, rect.y); }
    FRect Move(float alfa, sdl::FPoint &displacement, sdl::FPoint &escale) {
        // x' = x * x" * cos(α) + y * y" * sin(α) + dx
        // y' = -x * x" * sin(α) + y * y" * cos(α) + dy
        return {escale.X()*rect.x * static_cast<float>(cos(alfa)) +
                escale.Y()*rect.y * static_cast<float>(sin(alfa)) + escale.X()*displacement.X(),
                -escale.X()*rect.x * static_cast<float>(sin(alfa)) +
                escale.Y()*rect.y * static_cast<float>(cos(alfa)) + escale.Y()*displacement.Y(),
                rect.w, rect.h};
    }
    float &X() { return rect.x; }
    float &Y() { return rect.y; }
    float &W() { return rect.w; }
    float &H() { return rect.h; }
};

} // namespace

#endif // _SDL_RECT
