/*
 * Clases para manejar renderers en SDL2
 * SDL_CreateRenderer
 * SDL_DestroyRenderer
 * SDL_SetRenderDrawColor
 * SDL_RenderClear
 * SDL_RenderDrawLineF
 * SDL_RenderDrawPointF
 * SDL_RenderPresent
 */
#ifndef _SDL_RENDERER
#define _SDL_RENDERER

#include <vector>
#include <SDL.h>
#include "sdl_color.h"

namespace sdl {

class Renderer {
protected:
    SDL_Renderer *renderer;

public:
    Renderer() : renderer(NULL) {}
    Renderer(Window &window, SDL_RendererFlags flags) {
        renderer = SDL_CreateRenderer(window.get(), -1, flags);
    }
    ~Renderer() {
        SDL_DestroyRenderer(renderer);
    }
    operator SDL_Renderer*() { return renderer; }
    void SetDrawColor(Uint8 r, Uint8 g, Uint8 b, Uint8 a) {
        SDL_SetRenderDrawColor(renderer, r, g, b, a);
    }
    void SetDrawColor(const Color& color) {
        SDL_SetRenderDrawColor(renderer, color.GetR(), color.GetG(), color.GetB(), color.GetA());
    }
    void Clear() {
        SDL_RenderClear(renderer);
    }
    void DrawLinesF(std::vector<FPoint> puntos) {
        for(size_t i=0; i<puntos.size()-1; i++) {
            SDL_RenderDrawLineF(renderer, puntos[i].X(), puntos[i].Y(), puntos[i+1].X(), puntos[i+1].Y());
        }
    }
    void DrawPoint(FPoint punto) {
        SDL_RenderDrawPointF(renderer, punto.X(), punto.Y());
    }
    void DrawRect(FRect re) {
        SDL_RenderDrawRectF(renderer, re.get());
    }
    void Present() {
        SDL_RenderPresent(renderer);
    }
};

} // namespace

#endif // _SDL_RENDERER
